import React, {FC, useCallback, useEffect, useState} from "react";
import {Swiper, SwiperItem, Text, View} from "@tarojs/components";
import {brandApi, BrandRecord} from "@/api";
import styles from './info.module.scss'
import Taro, {useReachBottom, useRouter} from "@tarojs/taro";
import LineEllipsis from "@/components/textCollapse/collapse";
import Img from "@/components/image/image";
import Spin from "@/components/spinner";
import Collect from "@/components/collect/collect";
import ArticlesBox from "@/components/articlesBox/articlesBox";
import PageScript from "@/components/pageScript/pageScript";
import VideoPro from "@/components/videoPro"

type Params = {
  id: number
}
const BrandInfo: FC = () => {
  const {id} = useRouter().params as unknown as Params
  const [brandInfo, setBrandInfo] = useState<BrandRecord>()
  const [articleList, setArticleList] = useState<Articles[]>([])
  const [curIndex, setCurIndex] = useState<number>(1)
  const [page, setPage] = useState(1)
  const [total, setTotal] = useState(0)
  const [enable, setEnable] = useState(true)
  // const [maxHeight,setMaxHeight] = useState<number>(600)
  // const [maxWidth,setMaxWidth] = useState(750)

  let VideoRef = React.createRef<any>()
  Taro.useDidHide(() => {
    console.log("页面隐藏",VideoRef.current.func)
    // 视频被隐藏后自动暂停播放了，再打开自动继续播放了
    // VideoRef.current.func()
  })

  useEffect(() => {
    getData()
  }, [id])

  useEffect(() => {
    // console.log(brandInfo,'brandInfo')
    // let tempArr:any[] = []
    // if(brandInfo?.brand_album){
    //   tempArr.push(brandInfo.brand_album.split(',').map(item => {
    //     return item.split('?')[1].split('&')
    //   }))
    // }
    // if(brandInfo?.introductory_video_resource){
    //   tempArr.push([`width=${brandInfo?.introductory_video_resource.width}`,`height=${brandInfo?.introductory_video_resource.height}`])
    // }
    // console.log(tempArr,'tempArr')
    // tempArr?.reduce((accumulator, currentValue)=>{
    //   return accumulator = accumulator > currentValue[1].split('=')[1] ? accumulator : currentValue
    // })
  }, [brandInfo]);

  const getData = async () => {
    try {
      const data = await brandApi.info(id)
      Taro.setNavigationBarTitle({title: data.name})
      setBrandInfo(data)
      if(data.introductory_video) {
        Taro.request({
          url: `https://wfs.yaojiankang.top/files/${data.introductory_video}`,
          success: function (res) {
            if (res.data.ok) {
              setBrandInfo((data) => ({
                ...data!,
                introductory_video_resource: {
                  url: res.data.data.object.path,
                  width: res.data.data.object.width,
                  height: res.data.data.object.height,
                }
              }))
            }
          }
        })
      }
      const data1 = await brandApi.articleList(id, page)
      setTotal(data1.total)
      setArticleList([
        ...(articleList || []),
        ...data1.list
      ])
    } catch (e) {
      // setBrandInfo({disabled: 0, graphic_introduction: "", id: 0, introductory_video: "", name: "", brand_album:['1','2','3']})
    }
    setEnable(false)
  }

  Taro.useShareAppMessage((res) => {
    if(res.from === 'button'){

    }
    return {
      title:brandInfo?.name ?? '信桂',
      path: `/pages/preview/brand/info/info?id=${id}`
    }
  })

  Taro.useShareTimeline(() => {
    return {
      title: '信桂'
    }
  })

  useReachBottom(useCallback(() => {
    if (articleList?.length < total) {
      setPage(page + 1)
    }
  }, [total, articleList]))

  useEffect(() => {
    brandApi.articleList(id, page).then(res => {
      setTotal(res.total)
      setArticleList([
        ...(articleList || []),
        ...res.list
      ])
    })

  }, [page])

  function onChange(e) {
    setCurIndex(+e.detail.current + 1)
    VideoRef.current.func()
  }

  return (
    <View className='flex flex-column' style={{display: 'flex'}}>
      <Spin enable={enable} overlay/>
      {
        brandInfo?.introductory_video_resource?.url && !brandInfo?.brand_album?.length &&
        <View className={styles['swiper']}>
          <VideoPro onRef={VideoRef} src={brandInfo.introductory_video_resource.url}></VideoPro>
        </View>
      }
      {
        !brandInfo?.introductory_video_resource?.url && brandInfo?.brand_album?.length &&
        <>
        {
          brandInfo?.brand_album?.length > 1 ?
            <>
            <Swiper
              className={styles['swiper']}
              indicatorColor='#999'
              indicatorActiveColor='#333'
              indicatorDots={false}
              onChange={onChange}
            >

              {
                brandInfo.brand_album.split(',').map((d) =>
                  <SwiperItem key={d}>
                    <Img mode={'aspectFill'} width={750} height={600} src={d} errorType='brand'/>
                  </SwiperItem>)
              }
            </Swiper>
            <View className={styles.curIndexBox}>
              <Text className={'font-26'}>{curIndex}</Text>
              <Text>/</Text>
              <Text>{(brandInfo?.brand_album?.split(',').length || 0) + ((brandInfo && brandInfo.introductory_video_resource) ? 1 : 0)}</Text>
            </View>
            </>
              :
          <>
            {
              brandInfo?.brand_album?.split(',').map((d) =>
                <Img mode={'aspectFill'} width={750} height={600} src={d} errorType='brand'/>)
            }
          </>

        }
        </>
      }
      {
        (brandInfo?.introductory_video_resource?.url && brandInfo?.brand_album?.length) &&
        <>
          <Swiper
            className={styles['swiper']}
            indicatorColor='#999'
            indicatorActiveColor='#333'
            indicatorDots={false}
            onChange={onChange}
          >
            <SwiperItem>
              <VideoPro onRef={VideoRef} src={brandInfo.introductory_video_resource.url}></VideoPro>
            </SwiperItem>
            {
              brandInfo.brand_album.split(',').map((d) =>
                <SwiperItem key={d}>
                  <Img mode={'aspectFill'} width={750} height={600} src={d} errorType='brand'/>
                </SwiperItem>)
            }
          </Swiper>
          <View className={styles.curIndexBox}>
            <Text className={'font-26'}>{curIndex}</Text>
            <Text>/</Text>
            <Text>{(brandInfo?.brand_album?.split(',').length || 0) + ((brandInfo && brandInfo.introductory_video_resource) ? 1 : 0)}</Text>
          </View>
        </>
      }

      <View className={styles['body']}>
        <View className={styles['top']}>
          <View className='flex justify-between'>
            <Text className={`${styles['title']} flex-1`}>{brandInfo?.name}</Text>
            <Collect owner_type={4} owner_id={id} select={brandInfo?.collect} styles={{width: 'auto'}}/>
          </View>
          <LineEllipsis text={brandInfo?.graphic_introduction || '暂无简介'}/>
        </View>
        <View className={styles['bottom']}>
          {
            articleList?.length ? <>{
                articleList.map(d => <ArticlesBox key={d.id} data={d}/>)}
                <PageScript/>
              </>
              : <View className="py-6">
                <PageScript text="还没有发布文章"/>
              </View>
          }
        </View>
      </View>
    </View>
  );
}

export default BrandInfo
