import {FC, useEffect, useState} from "react";
import {Category} from "@/api";
import Taro from "@tarojs/taro";
import Empty from "@/components/empty/empty";
import {ScrollView, View} from "@tarojs/components";
import styles from "../sort.module.scss";
import Spin from "@/components/spinner";
import { illnessApi } from '@/api/illness'


interface Props {
  category: Category
  loading: boolean
  secondId: number
}

const prefix = 'SORT'
const SecondLevel: FC<Props> = ({category, loading,secondId,}) => {
  const [loadings,setLoadings] = useState(loading || true)
  const globalData = Taro.getApp().globalData
  const [id, setId] = useState<number>(0)
  const [illness, setIllness] = useState<Map<number, any[]>>(new Map)

  useEffect(() => {
    setId(secondId)
  }, [secondId]);

  useEffect(() => {
    changeSecond(id)
  }, [id]);

  function changeSecond(secondId?: number) {
    if (secondId) {
      setLoadings(true)
      illnessApi.list(secondId, 1, 500).then(res => {
        const data = new Map(illness)
        if (data.has(secondId)) {
          const newIllness = data.get(secondId)
          data.delete(secondId)
          data.set(secondId, res.list.reduce((pre, cur) => {
            const index = pre.findIndex(d => d.id === cur.id)
            if (index === -1) {
              pre.push(cur)
            } else {
              pre.splice(index, 1, cur)
            }
            return pre
          }, newIllness || []))
        } else {
          data.set(secondId, res.list)
        }
        setIllness(data)
        setLoadings(false)
      })
    }
  }
  function jump(id: number) {
    Taro.navigateTo({url: '/pages/preview/illness/list/list?id=' + id})
  }

  if (!category.resource_category?.length) {
    return (<Empty name='暂无二级分类'/>)
  } else {
    return (
      <View className='flex' style={{height: `${globalData.pageHeight}px`}}>
        <ScrollView scrollY className={styles.firstOrder} enhanced showScrollbar={false}>
          {
            category.resource_category?.map(d => <View
              id={`${prefix}-${d.id}`}
              key={d.id}
              onClick={() => setId(d.id)}
              className={id === d.id && styles.select}>
              {d.name}
            </View>)
          }
        </ScrollView>
        <ScrollView
          enhanced
          showScrollbar={false}
          scrollY
          className={styles.tree}
          scrollWithAnimation>
          <Spin enable={loadings} block/>
          {
            (secondId && illness.get(id)?.length) ?
              <>
                {
                  illness.get(id)?.map(d => <View
                    key={d.id}
                    className={styles.list}
                    onClick={() => jump(d.id)}>
                    {d.name}
                  </View>)
                }
                <View className='text-center font-24 text-dark mt-3 pb-2'>暂无更多</View>
              </>
              :
              <>
                {!loadings && <Empty name='暂无数据'/>}
              </>

          }
        </ScrollView>
      </View>
    )
  }
}

export default SecondLevel
