import {Swiper, SwiperItem, View} from "@tarojs/components";
import {FC, useMemo, useState} from "react";
import {Category, HomeApi} from "@/api";
import Taro from "@tarojs/taro";
import Tabs, {TabList} from "@/components/tabs/tabs";
import Empty from "@/components/empty/empty";
import Spin from "@/components/spinner";
import NavigationBar from "@/components/navigationBar/navigationBar";
import SecondLevel from "./components/secondLevel";


const Sort: FC = () => {
  const [data, setData] = useState<Category[]>([])
  const [firstId, setFirstId] = useState<number | undefined>(undefined)  // 一级选中

  const [enable, setEnable] = useState(true)
  const [loading, setLoading] = useState(false)
  const [secondId,setSecondId] = useState<number>(0)
  const globalData = Taro.getApp().globalData

  async function getData() {
    try {
      const res = await HomeApi.category(3)
      setData(res)
      if (res.length) {
        setFirstId(res[0].id)
        setSecondId(res[0].resource_category?.[0].id ?? 0)
      }
    } catch (e) {
      setLoading(false)
    }
    setEnable(false)
  }


  const getTabList = useMemo((): TabList[] => {
    return data.map<TabList>(d => ({
      title: d.name,
      value: d.id
    }))
  }, [data])

  function firstIdChange(id: number) {
    setFirstId(id)
    const resource_category = data.find(d => d.id === id)?.resource_category
    setSecondId(resource_category?.[0]?.id ?? 0)
  }

  Taro.useLoad(getData)



  function swiperChange(e) {
    const firstData = data[e.target.current]
    if (!firstData) return;
    setFirstId(firstData.id)
    setSecondId(firstData?.resource_category?.[0]?.id ?? 0)
  }


  return (
    <View>
      <NavigationBar leftNode={<Tabs
        tabList={getTabList}
        current={firstId}
        onChange={(data) => firstIdChange(data.tab?.value as number)}
      />}/>
      <Spin enable={enable} overlay/>
      {
        data.length > 0 ? <Swiper
            style={{height: `${globalData.pageHeight}px`}}
            onChange={swiperChange}
            current={data.findIndex(d => d.id === firstId)}>
            {
              data.map(d => <SwiperItem key={d.id}>
                <SecondLevel category={d} secondId={secondId} loading={loading} />
              </SwiperItem>)
            }
          </Swiper>
          : <Empty showBack onRefresh={getData} name='暂无疾病分类'/>
      }
    </View>
  )
}

export default Sort
