import { View, Text, Image} from "@tarojs/components";
import React, {FC, useState} from "react";
import Taro from "@tarojs/taro";
import styles from './videoFull.module.scss'
import {brandApi, HomeApi} from "@/api";
import Collect from "@/components/collect/collect";
import Spin from "@/components/spinner";
import VideoEvent from "@/hooks/videoEvent";
import palyWhite from '@/static/img/palyWhite.png'
import { getWfsInfo } from '@/utils/wfs'
import VideoPro from '@/components/videoPro'

interface Params {
  id: string
}

const VideoFull: FC = () => {
  const {id} = Taro.useRouter().params as unknown as Params
  // const video = Taro.createVideoContext('myVideo')
  // const [palying] = useState(false)
  const [data, setData] = useState<VideList | null>(null)
  const [enable, setEnable] = useState<boolean>(!Taro.getCurrentInstance().preloadData)
  const [timing, setTiming] = useState<NodeJS.Timeout | undefined>(undefined)

  const height: number = (data?.resource?.height ?? 1)/(data?.resource?.width ?? 1)*750
  console.log(height,'height')

  let VideoRef = React.createRef<any>()
  Taro.useDidHide(() => {
    console.log("页面隐藏",VideoRef.current.func)
    // 视频被隐藏后自动暂停播放了，再打开自动继续播放了
    // VideoRef.current.func()
  })

  Taro.useShareAppMessage((res) => {
    if(res.from === 'button'){

    }
    return {
      title:data?.title ?? '信桂',
      path: `/pages/preview/videoFull/videoFull?id=${id}`
    }
  })

  Taro.useShareTimeline(() => {
    return {
      title: '信桂'
    }
  })


  Taro.useLoad(() => {
    const preloadData: VideList = Taro.getCurrentInstance().preloadData as VideList
    if (preloadData) {
      setData(preloadData)
    }

    brandApi.videoInfo(id).then( async res => {
      if(res.resource_id){
        await getWfsInfo(res.resource_id).then(resp => {
          res.resource = { id: resp.id, name: resp.name, url: resp.object.path,thumb: resp.object.thumb,width:resp.object.width,height:resp.object.height }
        }).catch(()=>{

        })
        // await Taro.request({
        //   url: `https://wfs.yaojiankang.top/files/${res.resource_id}`,
        //   success: function (resp) {
        //     if(resp.data.ok){
        //       res.resource = { id: 0, name: '', url: '' }
        //       res.resource.url = resp.data.data.object.path
        //     }
        //   }
        // })
      }
      if (!res?.resource?.url) {
        Taro.showModal({
          title: '加载资源失败',
          confirmText: '退出',
          showCancel: true,
          success() {
            Taro.navigateBack()
          }
        })
      }
      setTiming(setTimeout(() => {
        HomeApi.voideView(Number(id)).then(() => {
          setData({
            ...res,
            video_view: res.video_view + 1
          })
          VideoEvent.videoAdd({id: Number(id), view: res.video_view + 1})
        })
      }, 3000))
      setData(res)
    }).catch(() => {
      if (!preloadData) {
        Taro.showModal({
          title: '加载资源失败',
          confirmText: '退出',
          showCancel: true,
          success() {
            Taro.navigateBack()
          }
        })
      }
    }).finally(() => {
      setEnable(false)
    })
  })

  Taro.useUnload(() => {
    clearTimeout(timing)
  })

  // function click() {
  //   if (palying) {
  //     video.pause()
  //   } else {
  //     video.play()
  //   }
  // }

  // function onError() {
  //   Taro.showModal({
  //     title: '视频播放错误',
  //     confirmText: '退出',
  //     showCancel: true,
  //     success() {
  //       Taro.navigateBack()
  //     }
  //   })
  // }

  return (
    <View>
      {
        data ? <>
          <View className={styles['container']}>
            {
              height != 750 && data?.resource?.url &&
              <View style={{margin:'auto'}}>
                <VideoPro onRef={VideoRef} src={data?.resource?.url} height={height} progress2bottom={true}></VideoPro>
              </View>
              // <Video
              //   style={{width:'750rpx',height:`${height}rpx`,}}
              //   objectFit={'fill'}
              //   id='myVideo'
              //   onClick={click}
              //   controls={false}
              //   autoplay={false}
              //   showBottomProgress='false'
              //   className={styles.video}
              //   src={data?.resource?.url}
              //   showCenterPlayBtn
              //   autoPauseIfOpenNative
              //   autoPauseIfNavigate
              //   playBtnPosition='center'
              //   showFullscreenBtn={false}
              //   enableProgressGesture={false}
              //   onPlay={() => setpalying(true)}
              //   onPause={() => setpalying(false)}
              //   onError={onError}
              //   onProgress={()=> video.play()}
              // />

            }
          <View className={styles.text}>
            <View className='font-32 font-weight'>{data.title}</View>
            <View className='font-28 mt-2 text-ellipsis-2'>{data.introduction}</View>
          </View>

          <View className={styles.title}>
            <View className='flex align-center mr-5'>
              <Image src={palyWhite} mode='widthFix' className={styles.img}/>
              <Text>{data.video_view}</Text>
            </View>
            <Collect owner_id={Number(id)}
                     owner_type={2}
                     styles={{color: '#fff'}}
                     select={data.collects}/>
          </View>
          </View>
        </> : <Spin enable={enable} overlay/>
      }

    </View>
  )
}

export default VideoFull
